==> cftp_0.9.orig.tar.gz: cftp-0.9/options.c <==
/*
   This file is automatically created from ``options.op''; don't make
   changes to this file, change ``options.op'' instead.
*/

#include <stddef.h>
#include "options.h"

int opt_mode = 'i';
extern void opts_mode();

int opt_tagchar = '>';

int ftp_hist_size = 200;
extern void ftp_set_hist_size();

int opt_beep = 0;

int opt_scrlimit = 0;

int opt_emacs_status = 1;
extern void opt_set_status();

char *opt_pager = "more";

char *openum_sort[] = { "none", "name", "date", "name-r", "date-r", NULL };
int opt_sort = 1;
extern void opt_set_sort();

int opt_wrap = 1;


struct uoption option[] = {
  { "mode" , "mo", "transfer mode for downloads",
    OPT_CHR, (void *)&opt_mode, opts_mode, NULL },
  { "tag-char" , "tc", "char to mark tagged files with",
    OPT_CHR, (void *)&opt_tagchar, NULL, NULL },
  { "hist-size" , "hs", "size of ftp command/response history",
    OPT_INT, (void *)&ftp_hist_size, ftp_set_hist_size, NULL },
  { "beep" , "bp", "beep after some commands",
    OPT_BOOL, (void *)&opt_beep, NULL, NULL },
  { "scroll-limit" , "sl", "minimum overlap for scrolling lists",
    OPT_INT, (void *)&opt_scrlimit, NULL, NULL },
  { "emacs-status" , "es", "Emacs like status line",
    OPT_BOOL, (void *)&opt_emacs_status, opt_set_status, NULL },
  { "pager" , "pg", "pager used to view files",
    OPT_STR, (void *)&opt_pager, NULL, NULL },
  { "sort" , "so", "sort criterium for directory listings",
    OPT_ENUM, (void *)&opt_sort, opt_set_sort, openum_sort },
  { "wrap" , "wa", "wrap around bottom/top when scrolling",
    OPT_BOOL, (void *)&opt_wrap, NULL, NULL },
  NULL, NULL, NULL, 0, NULL, NULL
};

==> cftp_0.10.orig.tar.gz: cftp-0.10/options.c <==
/*
   This file is automatically created from ``options.op''; don't make
   changes to this file, change ``options.op'' instead.
*/

#include <stddef.h>
#include "options.h"

int opt_mode = 'i';
extern void opts_mode();

int opt_pasv = 0;

int opt_tagchar = '>';

int ftp_hist_size = 200;
extern void ftp_set_hist_size();

int opt_beep = 0;

int opt_scrlimit = 0;

char *opt_pager = "more";

char *openum_sort[] = { "none", "name", "date", "name-r", "date-r", NULL };
int opt_sort = 1;
extern void opt_set_sort();

int opt_wrap = 1;


struct uoption option[] = {
  { "mode" , "mo", "transfer mode for downloads",
    OPT_CHR, (void *)&opt_mode, opts_mode, NULL },
  { "passive" , "pv", "use passive mode to establish data connections",
    OPT_BOOL, (void *)&opt_pasv, NULL, NULL },
  { "tag-char" , "tc", "char to mark tagged files with",
    OPT_CHR, (void *)&opt_tagchar, NULL, NULL },
  { "hist-size" , "hs", "size of ftp command/response history",
    OPT_INT, (void *)&ftp_hist_size, ftp_set_hist_size, NULL },
  { "beep" , "bp", "beep after some commands",
    OPT_BOOL, (void *)&opt_beep, NULL, NULL },
  { "scroll-limit" , "sl", "minimum overlap for scrolling lists",
    OPT_INT, (void *)&opt_scrlimit, NULL, NULL },
  { "pager" , "pg", "pager used to view files",
    OPT_STR, (void *)&opt_pager, NULL, NULL },
  { "sort" , "so", "sort criterium for directory listings",
    OPT_ENUM, (void *)&opt_sort, opt_set_sort, openum_sort },
  { "wrap" , "wa", "wrap around bottom/top when scrolling",
    OPT_BOOL, (void *)&opt_wrap, NULL, NULL },
  NULL, NULL, NULL, 0, NULL, NULL
};
